@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2020 ZNC, see the NOTICE file for details.
+ * Copyright (C) 2004-2024 ZNC, see the NOTICE file for details.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -93,6 +93,9 @@ class CIRCNetwork : private CCoreTranslationMixin {
     bool AddChan(CChan* pChan);
     bool AddChan(const CString& sName, bool bInConfig);
     bool DelChan(const CString& sName);
+    bool MoveChan(const CString& sChan, unsigned int index, CString& sError);
+    bool SwapChans(const CString& sChan1, const CString& sChan2,
+                   CString& sError);
     void JoinChans();
     void JoinChans(std::set<CChan*>& sChans);
 
@@ -153,6 +156,8 @@ class CIRCNetwork : private CCoreTranslationMixin {
     void IRCConnected();
     void IRCDisconnected();
     void CheckIRCConnect();
+    void NotifyClientsAboutServerDependentCap(const CString& sCap, bool bValue);
+    bool IsServerCapAccepted(const CString& sCap) const;
 
     bool PutIRC(const CString& sLine);
     bool PutIRC(const CMessage& Message);
