@@ -33,10 +33,11 @@
 #  define ZNC_EXPORT_LIB_DEPRECATED_NO_EXPORT ZNC_EXPORT_LIB_NO_EXPORT ZNC_EXPORT_LIB_DEPRECATED
 #endif
 
+/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
 #if 0 /* DEFINE_NO_DEPRECATED */
 #  ifndef ZNC_EXPORT_LIB_NO_DEPRECATED
 #    define ZNC_EXPORT_LIB_NO_DEPRECATED
 #  endif
 #endif
 
-#endif
+#endif /* ZNC_EXPORT_LIB_EXPORT_H */
